==> frysk-0.2.1.tar.bz2: frysk-0.2.1/frysk-sys/lib/unwind/ElfImage.java <==
// This file is part of the program FRYSK.
//
// Copyright 2007, Red Hat Inc.
//
// FRYSK is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by
// the Free Software Foundation; version 2 of the License.
//
// FRYSK is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with FRYSK; if not, write to the Free Software Foundation,
// Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
// 
// In addition, as a special exception, Red Hat, Inc. gives You the
// additional right to link the code of FRYSK with code not covered
// under the GNU General Public License ("Non-GPL Code") and to
// distribute linked combinations including the two, subject to the
// limitations in this paragraph. Non-GPL Code permitted under this
// exception must only link to the code of FRYSK through those well
// defined interfaces identified in the file named EXCEPTION found in
// the source code files (the "Approved Interfaces"). The files of
// Non-GPL Code may instantiate templates or use macros or inline
// functions from the Approved Interfaces without causing the
// resulting work to be covered by the GNU General Public
// License. Only Red Hat, Inc. may make changes or additions to the
// list of Approved Interfaces. You must obey the GNU General Public
// License in all respects for all of the FRYSK code and other code
// used in conjunction with FRYSK except the Non-GPL Code covered by
// this exception. If you modify this file, you may extend this
// exception to your version of the file, but you are not obligated to
// do so. If you do not wish to provide this exception without
// modification, you must delete this exception statement from your
// version and license this file solely under the GPL without
// exception.


package lib.unwind;

public class ElfImage
{

  final String name;

  long elfImage;

  long size;

  long segbase;

  long mapoff;

  int ret = 0;
  
  public ElfImage (String name, long elfImage, long size, long segbase, long mapoff)
  {
    this.name = name;
    this.elfImage = elfImage;
    this.size = size;
    this.segbase = segbase;
    this.mapoff = mapoff;
  }

  public ElfImage (int ret)
  {
    this.name = "ERROR: " + Integer.toString(ret);
    this.ret = ret;
  }

  public String toString ()
  {
    if (ret != 0)
      return "Bad Elf Image, ret: " + ret;

    return "Elf Image (" + name + "): 0x" + Long.toHexString(elfImage) + " size: " + size
	   + " segbase: 0x" + Long.toHexString(segbase) + " mapoff: 0x"
	   + Long.toHexString(mapoff);
  }

  public static native ElfImage mapElfImage (String elfImageName, long segbase,
					     long hi, long mapoff);

  // @Override
  native protected void finalize () throws Throwable;

}

==> frysk-0.4.tar.bz2: frysk-0.4/frysk-sys/lib/unwind/ElfImage.java <==
// This file is part of the program FRYSK.
//
// Copyright 2007, 2008, Red Hat Inc.
//
// FRYSK is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by
// the Free Software Foundation; version 2 of the License.
//
// FRYSK is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with FRYSK; if not, write to the Free Software Foundation,
// Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
// 
// In addition, as a special exception, Red Hat, Inc. gives You the
// additional right to link the code of FRYSK with code not covered
// under the GNU General Public License ("Non-GPL Code") and to
// distribute linked combinations including the two, subject to the
// limitations in this paragraph. Non-GPL Code permitted under this
// exception must only link to the code of FRYSK through those well
// defined interfaces identified in the file named EXCEPTION found in
// the source code files (the "Approved Interfaces"). The files of
// Non-GPL Code may instantiate templates or use macros or inline
// functions from the Approved Interfaces without causing the
// resulting work to be covered by the GNU General Public
// License. Only Red Hat, Inc. may make changes or additions to the
// list of Approved Interfaces. You must obey the GNU General Public
// License in all respects for all of the FRYSK code and other code
// used in conjunction with FRYSK except the Non-GPL Code covered by
// this exception. If you modify this file, you may extend this
// exception to your version of the file, but you are not obligated to
// do so. If you do not wish to provide this exception without
// modification, you must delete this exception statement from your
// version and license this file solely under the GPL without
// exception.

package lib.unwind;

/**
 * An object that, eventually, releases its underlying mmaped [elf]
 * data during a garbage collect.
 *
 * Since the garbage collect will, typically, occure after libunwind's
 * step has finished with the data this operation is safe.  However,
 * there is the real possibility of the GC occuring early, unmapping
 * the data causing an NPE.
 */

public class ElfImage {

    private final long image;
    private final long size;

    public ElfImage(long image, long size) {
	this.image = image;
	this.size = size;
    }
    // @Override
    protected void finalize() {
	unmap(image, size);
    }
    private static native void unmap(long image, long size);
}
